import { Server } from 'socket.io'
import { TSocket } from '../../../../utilities/types'
import { CharacterHair } from '@prisma/client'
import characterRepository from '../../../../repositories/characterRepository'
import { gameMasterLogger } from '../../../../utilities/logger'
import characterHairRepository from '../../../../repositories/characterHairRepository'

interface IPayload {}

export default class characterHairListEvent {
  constructor(
    private readonly io: Server,
    private readonly socket: TSocket
  ) {}

  public listen(): void {
    this.socket.on('gm:characterHair:list', this.handleEvent.bind(this))
  }

  private async handleEvent(data: IPayload, callback: (response: CharacterHair[]) => void): Promise<void> {
    const character = await characterRepository.getById(this.socket.characterId as number)
    if (!character) {
      gameMasterLogger.error('gm:characterHair:list error', 'Character not found')
      return callback([])
    }

    if (character.role !== 'gm') {
      gameMasterLogger.info(`User ${character.id} tried to list character hair but is not a game master.`)
      return callback([])
    }

    // get all objects
    const items = await characterHairRepository.getAll()
    callback(items)
  }
}
